==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1AggregationRuleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1AggregationRuleFluent<A extends V1AggregationRuleFluent<A>> extends Fluent<A>{


    public A addToClusterRoleSelectors(int index,V1LabelSelector item);
    public A setToClusterRoleSelectors(int index,V1LabelSelector item);
    public A addToClusterRoleSelectors(V1LabelSelector... items);
    public A addAllToClusterRoleSelectors(Collection<V1LabelSelector> items);
    public A removeFromClusterRoleSelectors(V1LabelSelector... items);
    public A removeAllFromClusterRoleSelectors(Collection<V1LabelSelector> items);
    
/**
 * This method has been deprecated, please use method buildClusterRoleSelectors instead.
 * @return The buildable object.
 */
@Deprecated public List<V1LabelSelector> getClusterRoleSelectors();
    public List<V1LabelSelector> buildClusterRoleSelectors();
    public V1LabelSelector buildClusterRoleSelector(int index);
    public V1LabelSelector buildFirstClusterRoleSelector();
    public V1LabelSelector buildLastClusterRoleSelector();
    public V1LabelSelector buildMatchingClusterRoleSelector(io.kubernetes.client.fluent.Predicate<V1LabelSelectorBuilder> predicate);
    public A withClusterRoleSelectors(List<V1LabelSelector> clusterRoleSelectors);
    public A withClusterRoleSelectors(V1LabelSelector... clusterRoleSelectors);
    public Boolean hasClusterRoleSelectors();
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> addNewClusterRoleSelector();
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> addNewClusterRoleSelectorLike(V1LabelSelector item);
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> setNewClusterRoleSelectorLike(int index,V1LabelSelector item);
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> editClusterRoleSelector(int index);
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> editFirstClusterRoleSelector();
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> editLastClusterRoleSelector();
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> editMatchingClusterRoleSelector(io.kubernetes.client.fluent.Predicate<V1LabelSelectorBuilder> predicate);

    public interface ClusterRoleSelectorsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V1AggregationRuleFluent.ClusterRoleSelectorsNested<N>>{

        
    public N and();    public N endClusterRoleSelector();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1AggregationRuleFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1AggregationRuleFluent<A extends V1AggregationRuleFluent<A>> extends Fluent<A>{


    public A addToClusterRoleSelectors(int index,V1LabelSelector item);
    public A setToClusterRoleSelectors(int index,V1LabelSelector item);
    public A addToClusterRoleSelectors(V1LabelSelector... items);
    public A addAllToClusterRoleSelectors(Collection<V1LabelSelector> items);
    public A removeFromClusterRoleSelectors(V1LabelSelector... items);
    public A removeAllFromClusterRoleSelectors(Collection<V1LabelSelector> items);
    
/**
 * This method has been deprecated, please use method buildClusterRoleSelectors instead.
 * @return The buildable object.
 */
@Deprecated public List<V1LabelSelector> getClusterRoleSelectors();
    public List<V1LabelSelector> buildClusterRoleSelectors();
    public V1LabelSelector buildClusterRoleSelector(int index);
    public V1LabelSelector buildFirstClusterRoleSelector();
    public V1LabelSelector buildLastClusterRoleSelector();
    public V1LabelSelector buildMatchingClusterRoleSelector(io.kubernetes.client.fluent.Predicate<V1LabelSelectorBuilder> predicate);
    public Boolean hasMatchingClusterRoleSelector(io.kubernetes.client.fluent.Predicate<V1LabelSelectorBuilder> predicate);
    public A withClusterRoleSelectors(List<V1LabelSelector> clusterRoleSelectors);
    public A withClusterRoleSelectors(V1LabelSelector... clusterRoleSelectors);
    public Boolean hasClusterRoleSelectors();
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> addNewClusterRoleSelector();
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> addNewClusterRoleSelectorLike(V1LabelSelector item);
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> setNewClusterRoleSelectorLike(int index,V1LabelSelector item);
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> editClusterRoleSelector(int index);
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> editFirstClusterRoleSelector();
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> editLastClusterRoleSelector();
    public V1AggregationRuleFluent.ClusterRoleSelectorsNested<A> editMatchingClusterRoleSelector(io.kubernetes.client.fluent.Predicate<V1LabelSelectorBuilder> predicate);

    public interface ClusterRoleSelectorsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V1AggregationRuleFluent.ClusterRoleSelectorsNested<N>>{

        
    public N and();    public N endClusterRoleSelector();
}


}
